@@ -88,6 +88,7 @@ class SystemConfigManifestProviderConan(base.SystemConfigManifestProvider):
         if self.execute_conan:
             env = os.environ.copy()
             # env["CONAN_USER_HOME"] = fs.path.join(working_dir_abs_path, "conan_home")
+            env["CONAN_ERROR_ON_OVERRIDE"] = "True"
 
             with importlib.resources.path(conan_generator, conan_export_resource) as conan_generator_path:
                 self.logger.log_info("Invoking: {}".format(" ".join(conan_export_invocation)))
@@ -164,4 +165,9 @@ class SystemConfigManifestProviderConan(base.SystemConfigManifestProvider):
         return self.toolchains_manifest
 
     def get_third_party_manifest(self):
-        return self.third_party_manifest
+
+        third_party_manifest_2 = {}
+        for k, v in self.third_party_manifest.items():
+            third_party_manifest_2[k] = base.ThirdPartyTargetInterface.from_dict(v)
+
+        return third_party_manifest_2
